.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _credible.api:

============
 Python API
============

This section includes information for using the Python API of ``credible``.


.. autosummary::
   :toctree: api

   credible.bayesian.metrics
   credible.bayesian.kfold
   credible.bayesian.functors
   credible.bayesian.utils
   credible.frequentist.functors
   credible.frequentist.utils
   credible.curves
   credible.plot
   credible.utils


.. include:: links.rst
